==> haskell-th-lift-0.8.6-1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-th-lift.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 th-lift
version:              0.8.6
visibility:           public
id:                   th-lift-0.8.6-HRVeiGNnDxNElRy2LmdExl
key:                  th-lift-0.8.6-HRVeiGNnDxNElRy2LmdExl
license:              BSD-3-Clause
copyright:
    © 2006 Ian Lynagh, © 2010-2019 Mathieu Boespflug, © 2019 Ryan Scott

maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Ian Lynagh
homepage:             http://github.com/RyanGlScott/th-lift
synopsis:             Derive Template Haskell'\''s Lift class for datatypes.
description:
    Derive Template Haskell'\''s @Lift@ class for datatypes using @TemplateHaskell@.
    The functionality in this package has largely been subsumed by the
    @DeriveLift@ language extension, which is available in GHC 8.0 and later
    versions. As such, this package is only useful as a way to backport bugfixes
    to @DeriveLift@ in later GHC versions back to older GHCs.

    The following libraries are related:

    * The <https://hackage.haskell.org/package/th-orphans th-orphans> package
    provides instances for @template-haskell@ syntax types.

    * The <http://hackage.haskell.org/package/th-lift-instances th-lift-instances>
    package provides @Lift@ instances for types in @base@, @text@,
    @bytestring@, @vector@, etc. Some of these instances are only provided for
    old versions of their respective libraries, as the same @Lift@ instances
    are also present upstream on newer versions.

category:             Language
abi:                  8149fd98eb7a6d122ace4780c53a73dd
exposed:              True
exposed-modules:
    Language.Haskell.TH.Lift Language.Haskell.TH.Lift.Internal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/th-lift-0.8.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/th-lift-0.8.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/th-lift-0.8.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-lift
hs-libraries:         HSth-lift-0.8.6-HRVeiGNnDxNElRy2LmdExl
depends:
    base-4.17.2.1 ghc-prim-0.9.1 template-haskell-2.19.0.0
    th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy

haddock-interfaces:   /usr/share/doc/haskell-th-lift/html/th-lift.haddock
haddock-html:         /usr/share/doc/haskell-th-lift/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-lift-0.8.6-2-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-th-lift.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 th-lift
version:              0.8.6
visibility:           public
id:                   th-lift-0.8.6-JhtmBkPIezsH36rizv7GIc
key:                  th-lift-0.8.6-JhtmBkPIezsH36rizv7GIc
license:              BSD-3-Clause
copyright:
    © 2006 Ian Lynagh, © 2010-2019 Mathieu Boespflug, © 2019 Ryan Scott

maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Ian Lynagh
homepage:             http://github.com/RyanGlScott/th-lift
synopsis:             Derive Template Haskell'\''s Lift class for datatypes.
description:
    Derive Template Haskell'\''s @Lift@ class for datatypes using @TemplateHaskell@.
    The functionality in this package has largely been subsumed by the
    @DeriveLift@ language extension, which is available in GHC 8.0 and later
    versions. As such, this package is only useful as a way to backport bugfixes
    to @DeriveLift@ in later GHC versions back to older GHCs.

    The following libraries are related:

    * The <https://hackage.haskell.org/package/th-orphans th-orphans> package
    provides instances for @template-haskell@ syntax types.

    * The <http://hackage.haskell.org/package/th-lift-instances th-lift-instances>
    package provides @Lift@ instances for types in @base@, @text@,
    @bytestring@, @vector@, etc. Some of these instances are only provided for
    old versions of their respective libraries, as the same @Lift@ instances
    are also present upstream on newer versions.

category:             Language
abi:                  064aa20ec7789b0ee83ff5e6ee219fc6
exposed:              True
exposed-modules:
    Language.Haskell.TH.Lift Language.Haskell.TH.Lift.Internal

import-dirs:          /usr/lib/ghc-9.6.7.20250817/site-local/th-lift-0.8.6
library-dirs:         /usr/lib/ghc-9.6.7.20250817/site-local/th-lift-0.8.6
library-dirs-static:  /usr/lib/ghc-9.6.7.20250817/site-local/th-lift-0.8.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-lift
hs-libraries:         HSth-lift-0.8.6-JhtmBkPIezsH36rizv7GIc
depends:
    base-4.18.3.0 ghc-prim-0.10.0 template-haskell-2.20.0.0
    th-abstraction-0.5.0.0-JZUv7luqGYXIX6vHGniH2t

haddock-interfaces:   /usr/share/doc/haskell-th-lift/html/th-lift.haddock
haddock-html:         /usr/share/doc/haskell-th-lift/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
